@@ -70,6 +70,8 @@ CDasherInterfaceBase::CDasherInterfaceBase()
   m_bGlobalLock = false;
   m_bShutdownLock = false;
 
+  m_bRedrawScheduled = false;
+
   m_pEventHandler = new CEventHandler(this);
  
   strCurrentContext = ". ";
@@ -448,7 +450,8 @@ void CDasherInterfaceBase::NewFrame(unsigned long iTime) {
     }
   }
 
-  Redraw(bChanged);
+  Redraw(bChanged || m_bRedrawScheduled);
+  m_bRedrawScheduled = false;
 
   // This just passes the time through to the framerate tracker, so we
   // know how often new frames are being drawn.
@@ -694,13 +697,12 @@ void CDasherInterfaceBase::ResetNats() {
 
 
 void CDasherInterfaceBase::InvalidateContext(bool bForceStart) {
-
   m_pDasherModel->m_strContextBuffer = "";
 
   Dasher::CEditContextEvent oEvent(10);
   m_pEventHandler->InsertEvent(&oEvent);
 
-  std::string strNewContext(m_pDasherModel->m_strContextBuffer);
+   std::string strNewContext(m_pDasherModel->m_strContextBuffer);
 
   // We keep track of an internal context and compare that to what
   // we are given - don't restart Dasher if nothing has changed.
@@ -726,12 +728,15 @@ void CDasherInterfaceBase::InvalidateContext(bool bForceStart) {
      WriteTrainFileFull();
    }
 
+  
+
    if(m_pDasherView)
      while( m_pDasherModel->CheckForNewRoot(m_pDasherView) ) {
        // Do nothing
      }
 
-   Redraw(true);
+   //   Redraw(true);
+   ScheduleRedraw();
 }
 
 
